From bcf5753276fcb7280924b46c7c49ef3e2388c9b0 Mon Sep 17 00:00:00 2001
From: Valentin Rothberg <rothberg@redhat.com>
Date: Wed, 8 Jan 2020 15:36:49 +0100
Subject: fix lint - pkg/varlinkapi/virtwriter

Signed-off-by: Valentin Rothberg <rothberg@redhat.com>
---
 pkg/varlinkapi/virtwriter/virtwriter.go | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

(limited to 'pkg')

diff --git a/pkg/varlinkapi/virtwriter/virtwriter.go b/pkg/varlinkapi/virtwriter/virtwriter.go
index dd171943f..d96e82a3f 100644
--- a/pkg/varlinkapi/virtwriter/virtwriter.go
+++ b/pkg/varlinkapi/virtwriter/virtwriter.go
@@ -27,13 +27,13 @@ const (
 	TerminalResize SocketDest = iota
 	// Quit and detach
 	Quit SocketDest = iota
-	// Quit from the client
+	// HangUpFromClient hangs up from the client
 	HangUpFromClient SocketDest = iota
 )
 
-// ClientHangup signifies that the client wants to drop its
-// connection from the server
-var ClientHangup = errors.New("client hangup")
+// ErrClientHangup signifies that the client wants to drop its connection from
+// the server.
+var ErrClientHangup = errors.New("client hangup")
 
 // IntToSocketDest returns a socketdest based on integer input
 func IntToSocketDest(i int) SocketDest {
@@ -177,7 +177,7 @@ func Reader(r *bufio.Reader, output, errput, input io.Writer, resize chan remote
 			//
 			// reproducer: echo hello | (podman-remote run -i alpine cat)
 			time.Sleep(1 * time.Second)
-			return ClientHangup
+			return ErrClientHangup
 		default:
 			// Something really went wrong
 			return errors.New("unknown multiplex destination")
-- 
cgit v1.2.3-54-g00ecf